#!/bin/bash

# -------------------------------------------------------------------
# Copyright (C) 2015 by Intevation GmbH
# Author(s):
# Sascha Wilde <wilde@intevation.de>
# Frank Koormann <frank@intevation.de>

# This program is free software under the GNU GPL (>=v2)
# Read the file COPYING coming with the software for details.
# -------------------------------------------------------------------

# Die on errors!
set -e 

ME=`basename $0`

usage ()
{
  cat <<EOF
$ME [-r] [-c] [-s] ID 

Trägt JMD mit ID aus den Auswertungsdatenbanken
von Trägergruppe, BMFSFJ und Servicebüro JMD aus.

Explizite Optionen für die Austragung aus einzelnen DBs
- [-r] Respekt Coaches
- [-c] Fallakten (Case Management)
- [-s] Strukturdaten (JMD-Statistik)
EOF
  exit 0
}

fatal ()
{
  echo >&2 "FATAL: $*"
  exit 23
}


check_user ()
{
  [ `id -nu` == "postgres" ] || fatal "$ME must be run as user postgres"
}

get_port ()
# Args: $1 = ID
# Return DB Port for given ID
{
  case $1 in
    3*)
      echo 5432
      return
      ;;
    2*)
      echo 5433
      return
      ;;
    4*)
      echo 5434
      return
      ;;
    1*)
      echo 5435
      return
      ;;
    *)
      fatal "Could not determine db port for id $1"
      ;;
  esac
}

get_traegergruppe_id ()
# Args: $1 = ID
# Return traegergruppe_id for given ID
{
  case $1 in
    3*)
      echo 3000
      return
      ;;
    2*)
      echo 2000
      return
      ;;
    4*)
      echo 4000
      return
      ;;
    1*)
      echo 1000
      return
      ;;
    *)
      fatal "Could not determine db port for id $1"
      ;;
  esac
}

get_traegergruppe ()
# Args: $1 = ID
# Return traegergruppe for given ID
{
  case $1 in
    3*)
      echo awo
      return
      ;;
    2*)
      echo ejsa
      return
      ;;
    4*)
      echo ib
      return
      ;;
    1*)
      echo kjs
      return
      ;;
    *)
      fatal "Could not determine db port for id $1"
      ;;
  esac
}

#-----------------------------------------------------------------------
# Main

RC=0
CM=0
ST=0
while getopts ":rcs" opt; do
  case $opt in
    r)
      RC=1
      ;;
    c)
      CM=1
      ;;
    r)
      ST=1
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
  esac
done
shift $((OPTIND-1))

if [ $# -lt 1 ] ; then
    usage
fi

check_user
jmd_id="$1"

port=`get_port $jmd_id`
traegergruppe=`get_traegergruppe $jmd_id`

echo -n "Ausgetragen:"

if [ $RC == 1 ] ; then
    psql -p $port ka_rc$traegergruppe\auswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"
    
    psql -p 5436 ka_rcbmfsfjauswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"
    
    psql -p 5437 ka_rcservicestelleauswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"

    echo -n " RC"
fi

if [ $CM == 1 ] ; then
    psql -p $port ka_$traegergruppe\auswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"
    
    psql -p 5436 ka_bmfsfjauswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"
    
    psql -p 5437 ka_servicestelleauswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"

    echo -n " CM"
fi

if [ $ST == 1 ] ; then
    psql -p $port ka_st$traegergruppe\auswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"

    psql -p 5436 ka_stbmfsfjauswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"

    psql -p 5437 ka_stservicestelleauswertung102_db \
	    -c "DELETE FROM fkz_tbl where fkz = '$jmd_id';"

    echo -n " ST"
fi
