#!/bin/sh
set -e
set -x

get_port ()
# Args: $1 = ID
# Return DB Port for given ID
{
  case $1 in
    3*)
      echo 5432
      return
      ;;
    2*)
      echo 5433
      return
      ;;
    4*)
      echo 5434
      return
      ;;
    1*)
      echo 5435
      return
      ;;
    *)
      fatal "Could not determine db port for id $1"
      ;;
  esac
}

FKZBASE="$1"
TYPE=jmd
DBHOST=localhost
DBPORT=`get_port $FKZBASE`
EXPORTHOST=jmd-auswertung.intevation.de
EXPORTUSER=mpuls
EXPORTCOMMAND=/home/mpuls/${TYPE}/releases/current/evaluation-transfer/export-sqlite.py
TEMPLATEDIR=/home/mpuls/${TYPE}/transfer-coaches
DATADIR=${TEMPLATEDIR}/data/${FKZBASE}
TEMPLATEDB=$TEMPLATEDIR/template-coaches${FKZBASE}.db

DATE=`date +"%Y-%m-%d"`
EXPORTFILE=$DATADIR/${TYPE}-$DATE.db
cp $TEMPLATEDB $EXPORTFILE
chmod 666 $EXPORTFILE
echo "Exporting databases"
sudo -u postgres $EXPORTCOMMAND -o $EXPORTFILE -p $DBPORT \
                     -r "rg_gruppenangebote,nm_klassenstufen:rg_gruppenangebote,nm_inhalte:rg_gruppenangebote,nm_format:rg_gruppenangebote,nm_methode:rg_gruppenangebote,rg_case_document_count,coaches_stellen" \
                     --blacklist="id,uuid_id,individuelle_beratungen_gesamt,klassenstufen,inhalte,format,methode" \
                     --fkz-relations="coaches_stellen"
bzip2 $EXPORTFILE
chmod 640 $EXPORTFILE.bz2

echo "Transfering databases"
scp -qp ${EXPORTFILE}.bz2 ${EXPORTUSER}@${EXPORTHOST}:${DATADIR}
echo "Done :)"
