BEGIN;
-- issue2201: add field
SET ROLE :db_adm;

INSERT INTO db_history (beschreibung, zeitpunkt)
VALUES ('1.1/10_integrationskurse.sql', current_timestamp);


-- ----------------------------------------------------------
-- Adds a new dropdown "Träger bietet Integrationskurse an"
-- ----------------------------------------------------------

-- The yes/no/maybe table was originally this one, but since the new one is
-- nearer the beginning of the table, we will replace all references

-- Added IF EXISTS statement because former update fails because table wasn't
-- present anymore. New created databases und upgraded databases seems not to
-- be in sync and shows differences in schema :(
DROP TABLE IF EXISTS existenz_jugendhilfekonferenz_tbl CASCADE;
-- löscht ebenfalls Constraint rg_kooperationsbezug_tbl_kontakt_besteht_ueber_gremien_fkey für Tabelle rg_kooperationsbezug_tbl
-- löscht ebenfalls Constraint rg_kooperationsbezug_tbl_besteht_informationsaustausch_fkey für Tabelle rg_kooperationsbezug_tbl
-- löscht ebenfalls Constraint rg_kooperationsbezug_tbl_institution_unterstuetzt_aktiv_fkey für Tabelle rg_kooperationsbezug_tbl
-- löscht ebenfalls Constraint master_tbl_erstellung_netzwerkkarte_fkey für Tabelle master_tbl
-- löscht ebenfalls Constraint master_tbl_teilnahme_jugenkonferenz_fkey für Tabelle master_tbl
-- löscht ebenfalls Constraint master_tbl_existenz_jugendkonferenz_fkey für Tabelle master_tbl
-- löscht ebenfalls Constraint master_tbl_teilnahme_jugenhilfekonferenz_fkey für Tabelle master_tbl
-- löscht ebenfalls Constraint master_tbl_existenz_jugendhilfekonferenz_fkey für Tabelle master_tbl
DROP TABLE IF EXISTS erstellung_netzwerkkarte_tbl CASCADE;



CREATE TABLE traeger_integrationskurs_tbl (
    id SERIAL PRIMARY KEY NOT NULL,
    value VARCHAR(13) NOT NULL
);

INSERT INTO traeger_integrationskurs_tbl (id, value) VALUES (-3, 'Unbekannt');
INSERT INTO traeger_integrationskurs_tbl (id, value) VALUES (-1, 'Keine Angabe');
INSERT INTO traeger_integrationskurs_tbl (id, value) VALUES (0, 'Nein');
INSERT INTO traeger_integrationskurs_tbl (id, value) VALUES (1, 'Ja');

GRANT SELECT ON traeger_integrationskurs_tbl TO GROUP :cm_group;
GRANT SELECT ON traeger_integrationskurs_tbl TO GROUP :admin_group;



DROP VIEW master_tbl_view CASCADE;
-- löscht ebenfalls Regel _RETURN für Sicht master_tbl_anonym_view
-- löscht ebenfalls Sicht master_tbl_anonym_view
-- löscht ebenfalls Regel master_tbl_anonym_insert_rule für Sicht master_tbl_anonym_view
-- löscht ebenfalls Regel master_tbl_anonym_delete_rule für Sicht master_tbl_anonym_view

DROP VIEW master_tbl_eval_total_view CASCADE;
-- löscht ebenfalls Regel _RETURN für Sicht master_tbl_eval_incm_view
-- löscht ebenfalls Sicht master_tbl_eval_incm_view


ALTER TABLE master_tbl ADD COLUMN traeger_integrationskurs INTEGER DEFAULT -1;

ALTER TABLE master_tbl ADD CONSTRAINT master_tbl_erstellung_netzwerkkarte_fkey FOREIGN KEY (erstellung_netzwerkkarte) REFERENCES traeger_integrationskurs_tbl (id);
ALTER TABLE master_tbl ADD CONSTRAINT master_tbl_teilnahme_jugenkonferenz_fkey FOREIGN KEY (teilnahme_jugenkonferenz) REFERENCES traeger_integrationskurs_tbl (id);
ALTER TABLE master_tbl ADD CONSTRAINT master_tbl_existenz_jugendkonferenz_fkey FOREIGN KEY (existenz_jugendkonferenz) REFERENCES traeger_integrationskurs_tbl (id);
ALTER TABLE master_tbl ADD CONSTRAINT master_tbl_teilnahme_jugenhilfekonferenz_fkey FOREIGN KEY (teilnahme_jugenhilfekonferenz) REFERENCES traeger_integrationskurs_tbl (id);
ALTER TABLE master_tbl ADD CONSTRAINT master_tbl_existenz_jugendhilfekonferenz_fkey FOREIGN KEY (existenz_jugendhilfekonferenz) REFERENCES traeger_integrationskurs_tbl (id);

ALTER TABLE rg_kooperationsbezug_tbl ADD CONSTRAINT rg_kooperationsbezug_tbl_kontakt_besteht_ueber_gremien_fkey FOREIGN KEY (kontakt_besteht_ueber_gremien) REFERENCES traeger_integrationskurs_tbl (id);
ALTER TABLE rg_kooperationsbezug_tbl ADD CONSTRAINT rg_kooperationsbezug_tbl_besteht_informationsaustausch_fkey FOREIGN KEY (besteht_informationsaustausch) REFERENCES traeger_integrationskurs_tbl (id);
ALTER TABLE rg_kooperationsbezug_tbl ADD CONSTRAINT rg_kooperationsbezug_tbl_institution_unterstuetzt_aktiv_fkey FOREIGN KEY (institution_unterstuetzt_aktiv) REFERENCES traeger_integrationskurs_tbl (id);





-- ----------------------------------------------------------
-- Replace the VIEWS and rules
-- ----------------------------------------------------------
CREATE OR REPLACE VIEW master_tbl_view
AS SELECT 
     *
FROM master_tbl
WHERE
    master_tbl.bearbeiter_id = getuserid()
    OR master_tbl.id IN (
        SELECT nm.master_id from nm_benutzer_master_tbl nm
        WHERE nm.benutzer_id IN (
            SELECT nm2.gruppe_id from nm_benutzer_gruppe_tbl nm2 
            WHERE nm2.benutzer_id = getuserid()
        )
    )
    OR pg_has_role('admin','MEMBER');

CREATE OR REPLACE RULE master_tbl_update_rule AS ON UPDATE TO master_tbl_view
DO INSTEAD UPDATE master_tbl SET
    phase = NEW.phase,
    datum_begin_zeitraum = NEW.datum_begin_zeitraum,
    datum_ende_zeitraum = NEW.datum_ende_zeitraum,
    raeumliche_zustaendigkeit = NEW.raeumliche_zustaendigkeit,
    raeumliche_zustaendigkeit_nennung = NEW.raeumliche_zustaendigkeit_nennung,
    nennung_zustaendigkeit = NEW.nennung_zustaendigkeit,
    jmdstruktur = NEW.jmdstruktur,
    traeger_integrationskurs = NEW.traeger_integrationskurs,
    anzahl_ha_stellenteile = NEW.anzahl_ha_stellenteile,
    anzahl_ha_personen = NEW.anzahl_ha_personen,
    anzahl_ha_maennlich = NEW.anzahl_ha_maennlich,
    anzahl_ha_weiblich = NEW.anzahl_ha_weiblich,
    anzahl_ha_migration = NEW.anzahl_ha_migration,
    ha_sprachkenntnis_arabisch = NEW.ha_sprachkenntnis_arabisch,
    ha_sprachkenntnis_englisch = NEW.ha_sprachkenntnis_englisch,
    ha_sprachkenntnis_franzoesisch = NEW.ha_sprachkenntnis_franzoesisch,
    ha_sprachkenntnis_polnisch = NEW.ha_sprachkenntnis_polnisch,
    ha_sprachkenntnis_russisch = NEW.ha_sprachkenntnis_russisch,
    ha_sprachkenntnis_spanisch = NEW.ha_sprachkenntnis_spanisch,
    ha_sprachkenntnis_tuerkisch = NEW.ha_sprachkenntnis_tuerkisch,
    ha_sprachkenntnis_sonstige = NEW.ha_sprachkenntnis_sonstige,
    ha_sprachkenntnisse_sonstige_nennung = NEW.ha_sprachkenntnisse_sonstige_nennung,
    verteilung_aa_begleitung_cm = NEW.verteilung_aa_begleitung_cm,
    verteilung_aa_betreuung = NEW.verteilung_aa_betreuung,
    verteilung_aa_gruppenangebote = NEW.verteilung_aa_gruppenangebote,
    verteilung_aa_netzwerkarbeit = NEW.verteilung_aa_netzwerkarbeit,
    verteilung_aa_oeffentlichkeit = NEW.verteilung_aa_oeffentlichkeit,
    verteilung_aa_evaluation = NEW.verteilung_aa_evaluation,
    verteilung_aa_leitung = NEW.verteilung_aa_leitung,
    verteilung_aa_elternarbeit = NEW.verteilung_aa_elternarbeit,
    verteilung_aa_freiwilligenarbeit = NEW.verteilung_aa_freiwilligenarbeit,
    verteilung_aa_dokumentation = NEW.verteilung_aa_dokumentation,
    verteilung_aa_sonstiges = NEW.verteilung_aa_sonstiges,
    verteilung_aa_sonstiges_nennung = NEW.verteilung_aa_sonstiges_nennung,
    anzahl_nha_stellenteile = NEW.anzahl_nha_stellenteile,
    anzahl_nha_personen = NEW.anzahl_nha_personen,
    anzahl_nha_maennlich = NEW.anzahl_nha_maennlich,
    anzahl_nha_weiblich = NEW.anzahl_nha_weiblich,
    anzahl_nha_migration = NEW.anzahl_nha_migration,
    anzahl_nha_stundenunfang = NEW.anzahl_nha_stundenunfang,
    anzahl_ea_personen = NEW.anzahl_ea_personen,
    anzahl_ea_maennlich = NEW.anzahl_ea_maennlich,
    anzahl_ea_weiblich = NEW.anzahl_ea_weiblich,
    anzahl_ea_migration = NEW.anzahl_ea_migration,
    bildungsberatung_garantiefonds = NEW.bildungsberatung_garantiefonds,
    bildungsberatung_beratungsfaelle = NEW.bildungsberatung_beratungsfaelle,
    existenz_jugendhilfekonferenz = NEW.existenz_jugendhilfekonferenz,
    teilnahme_jugenhilfekonferenz = NEW.teilnahme_jugenhilfekonferenz,
    existenz_jugendkonferenz = NEW.existenz_jugendkonferenz,
    teilnahme_jugenkonferenz = NEW.teilnahme_jugenkonferenz,
    erstellung_netzwerkkarte = NEW.erstellung_netzwerkkarte,
    mitarbeit_gremien = NEW.mitarbeit_gremien,
    weiter_akt_art_interkulturell = NEW.weiter_akt_art_interkulturell,
    weiter_akt_art_aufsuchende = NEW.weiter_akt_art_aufsuchende,
    weiter_akt_art_eltern = NEW.weiter_akt_art_eltern,
    weiter_akt_art_freiwilligerdienst = NEW.weiter_akt_art_freiwilligerdienst,
    weiter_akt_art_sonstiges = NEW.weiter_akt_art_sonstiges,
    weitere_akt_anzahl_informationsveranst = NEW.weitere_akt_anzahl_informationsveranst,
    weitere_akt_anzahl_workshops = NEW.weitere_akt_anzahl_workshops,
    weitere_akt_anzahl_trainings = NEW.weitere_akt_anzahl_trainings,
    weitere_akt_anzahl_veroeffentlichungen = NEW.weitere_akt_anzahl_veroeffentlichungen,
    weitere_akt_anzahl_referate = NEW.weitere_akt_anzahl_referate,
    weitere_akt_anzahl_sonstiges = NEW.weitere_akt_anzahl_sonstiges,
    elternberatung_anzahl = NEW.elternberatung_anzahl,
    elternberatung_stunden = NEW.elternberatung_stunden,
    weitere_akt_weitere_angaben = NEW.weitere_akt_weitere_angaben
WHERE id = NEW.id;

CREATE OR REPLACE RULE master_tbl_delete_rule AS ON DELETE TO master_tbl_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE master_tbl_insert_rule AS ON INSERT TO master_tbl_view
    DO INSTEAD NOTHING;

GRANT SELECT ON master_tbl_view TO GROUP :cm_group;
GRANT UPDATE ON master_tbl_view TO GROUP :cm_group;
GRANT SELECT ON master_tbl_view TO GROUP :admin_group;








CREATE OR REPLACE VIEW master_tbl_anonym_view
AS SELECT
    * FROM master_tbl_view;

CREATE OR REPLACE RULE master_tbl_anonym_delete_rule AS ON DELETE TO master_tbl_anonym_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE master_tbl_anonym_insert_rule AS ON INSERT TO master_tbl_anonym_view
    DO INSTEAD NOTHING;

GRANT SELECT ON master_tbl_anonym_view TO GROUP :cm_group;
GRANT SELECT ON master_tbl_anonym_view TO GROUP :admin_group;







CREATE OR REPLACE  VIEW master_tbl_eval_total_view AS
SELECT m.* FROM master_tbl m JOIN ka_status_tbl s
    ON m.id = s.master_id
    WHERE
        s.status <> 3
        OR pg_has_role('admin','MEMBER');
GRANT SELECT ON master_tbl_eval_total_view TO GROUP :cm_group;
GRANT SELECT ON master_tbl_eval_total_view TO GROUP :admin_group;


CREATE OR REPLACE  VIEW master_tbl_eval_incm_view AS
SELECT * FROM master_tbl_eval_total_view
    WHERE phase IN (1);

GRANT SELECT ON public.master_tbl_eval_incm_view TO :cm_group;
GRANT SELECT ON public.master_tbl_eval_incm_view TO :admin_group;






--
-- Finish
--
SET ROLE postgres;
-- ROLLBACK;
COMMIT;
