-- Upgrade script for the changes to create_master_ds and
-- initial_master_ds_owner_id.

-- NOTE: This copy of the script
-- db-admin/sql/upgrades/1.2.5/02_initial_master_ds_owner.sql does not
-- contain the definition of initial_master_ds_owner_id because that is
-- already defined in an application specific way in
-- install-struktur/config/09struktur.sql
--
-- This version of create_master_ds also doesn't call
-- create_meta_ds(mid) because create_meta_ds does not usually exist in
-- JMD struktur databases.


CREATE OR REPLACE FUNCTION create_master_ds(nuuid char(36))
    RETURNS integer
    LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER AS
$$
DECLARE
    ownerid integer;
    standin integer;
    mid     integer;
BEGIN
    ownerid := initial_master_ds_owner_id();
    INSERT INTO master_tbl (bearbeiter_id) VALUES (ownerid);
    SELECT INTO standin vertreter from ka_benutzer_tbl WHERE id = ownerid;

    IF standin IS NOT NULL THEN
        INSERT INTO nm_benutzer_master_tbl(benutzer_id, master_id)
                VALUES (standin, currval('master_tbl_id_seq'));
    END IF;

    SELECT INTO mid currval('master_tbl_id_seq');

    IF nuuid IS NOT NULL THEN
        UPDATE master_tbl SET uuid_id = nuuid WHERE id = mid;
    ELSE
        PERFORM set_uuid('master_tbl', mid);
    END IF;

    PERFORM create_status_ds(mid);

    -- The default implementation calls create_meta_ds which is not
    -- present in all JMD databases (particularly not
    -- struktur-databases). We do not use a meta-server in the struktur
    -- part so we simply do not call create_meta_ds at all for now. This
    -- is probably not the right fix, especially because with this
    -- upgrade script, the existing databases differ slightly from ones
    -- installed later. Differences between databases (except for the
    -- actual data stored in them, obviously) need to be avoided, so
    -- this really needs to be fixed in a different way, but this
    -- upgrade should fix the immediate problems we have.
    -- See mpuls/issue5108, mpuls/issue5079
    -- PERFORM create_meta_ds(mid);

    RETURN mid;
END;
$$;

REVOKE ALL ON FUNCTION create_master_ds(char(36)) FROM PUBLIC;
GRANT EXECUTE ON FUNCTION create_master_ds(char(36))
    TO GROUP :cm_group;
