# -*- coding: utf-8 -*-
# Copyright 2007, 2008, 2014 Intevation GmbH, Germany, <info@intevation.de>
# 
# This file is part of mpuls JMD (CoMPUter-based case fiLeS - 
# Web-Anwendungs-Server fuer Kompetenzagenturen).
# 
# mpuls JMD is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
# 
# mpuls JMD is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
# 
# You should have received a copy of the GNU Affero General Public
# License along with mpuls JMD. If not, see <http://www.gnu.org/licenses/>.
# 
# mpuls JMD has been developed on behalf of the 
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
# European Social Fund resources.
import logging
from datetime import datetime, timedelta

import mpulsweb.lib.helpers as h
from mpulsweb.lib.base import session, g
from mpulsweb.lib.db import db
from mpulsweb.model.case import MpulsCaseOverview
from mpulsweb.model.agencysettings import Agency

from mpulsweb.model.appointment import AppointmentOverview, CaseAppointmentFactory, TagsReminderOverview

log = logging.getLogger(__name__)

class StatisticReminderOverview(AppointmentOverview):

    def __init__(self):
        self.appointment_list = []
        agency = Agency()
        maxage = agency.getMaxSavetime()
        cases = MpulsCaseOverview()
        user = session['USER_AUTHORIZED']

        # 0. Load ids and some additional info on cases which either are active
        # but seems to be orphaned or are finished and not edited for
        # longer than maxage.
        # orphaned means that all last appointments, aids or the
        # modification date is older than maxage

        # Issue1422
        #oldAndActive = self.check_recent_statistic(maxage, user)
        #if not oldAndActive:
        #    case = self.get_recent_statistic(maxage, user)
        #    appointment = self.makeAppointment(case)
        #    self.appointment_list.append(appointment)

    def get_recent_statistic(self, days, user):
        conn, cur = None, None
        try:
            conn = db.getConnection()
            cur = conn.cursor()
            sql = ("SELECT id, datum_begin_zeitraum, datum_ende_zeitraum \
                    from master_tbl_view \
                    order by datum_begin_zeitraum desc")
            cur.execute(sql, {'maxdays': days})
            log.debug(cur.query)
            result = cur.fetchone()
           
            if result is not None:
                case = {'id': result[0], 'start': result[1], 'end': result[2]}
                return case 
        finally:
            db.recycleConnection(conn, cur)
        return {} 

    def check_recent_statistic(self, days, user):
        conn, cur = None, None
        list = {}
        try:
            conn = db.getConnection()
            cur = conn.cursor()
            sql = ("SELECT id, datum_begin_zeitraum, datum_ende_zeitraum \
                    from master_tbl_view where \
                    extract(\
                        day from (now() - datum_begin_zeitraum)\
                    ) < %(maxdays)s \
                    order by datum_begin_zeitraum desc")
            cur.execute(sql, {'maxdays': days})
            log.debug(cur.query)
            result = cur.fetchall()
            for r in result:
                list[r[0]] = {'start': r[1], 'end': r[2]}
            return list
        finally:
            db.recycleConnection(conn, cur)
        return False

    def makeAppointment(self, case):
        factory     = CaseAppointmentFactory()
        type        = 1
        title       = u"Neue JMD-Statistik erstellen"
        description = u"Für den aktuellen Zeitraum konnte keine JMD-Statistik \
                    gefunden werden. Die letzte JMD-Statistik ist für den \
                    Zeitraum"
        appointment = factory.createByData(None,
                                            title,
                                            case.get('start'),
                                            case.get('end'),
                                            description,
                                            case.get('id'),
                                            type)
        return appointment

class TagsReminderOverview(TagsReminderOverview):
    def getUserId(self):
        """
        Return the real user-ID of the user owning cases in the structure
        part, not the one from the user logged in
        """
        return 1
# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
