## -*- coding: utf-8 -*-
<%!

from pylons import app_globals as g
import mpulsweb.lib.helper.filters as F
import mpulsweb.lib.helpers as h
from mpulsweb.lib.translation import _

all_roles = ['admin', 'cm']

## Fields to show in the case list.  Each entry is a tuple of the form
##     (TITLE, FIELDNAME, STYLE, ROLES, FORMATTER)
## Here, TITLE is the title of the field, FIELDNAME is the field name
## used in the search URL that's built for each column, STYLE is a CSS
## class name to use in the style attribute of the HTML TH-element,
## ROLES is a list with the names of the roles for which the field
## should be shown.  Finally, FORMATTER is a python callable that is
## called with the case object as argument and which should return the
## formatted value for the column.

fields = []
for d in g.case.get_overview_fields():
  f = d.name
  fn = d.overview_label
  fs = d.overview_style
  field = (fn,f,fs, all_roles,
           lambda case, d=d: h.shorten(h.format_object(case.get_value(d.name)), d.overview_length))
  fields.append(field)

# Extend fields with default fields in overview
fields.extend([(_('Updated'), "zugriff", "table_name", ["cm", "admin"],
     lambda case: h.format_date(case.state.getAccessTime())),
  ])
%>

<%def name="build_list_headers()">
  % if g.mpuls_config.is_enabled('case-module', 'casebundle'):
    <th class="table_header_h table_checkbox">&nbsp;</th>
  % endif
  % for title, urlpart, style, roles, get_value in fields:
    % if h.hasRole(roles):
      <th class="${style} table_header_h">${title}
        <a href="${h.url(controller='case_overview', action='overview',
                             sort_field=urlpart, sort_order='asc')}">
            %if c.sort_field == urlpart and c.sort_order == 'asc':
              <svg class="svg-sort-active" aria-labelledby="title" role="img">
                <title id="title">${_("Sorted by %s in ascending order") % title}</title>
            %else:
              <svg class="svg-sort" aria-labelledby="title" role="img">
                <title id="title">${_("Sort in ascending orde")}</title>
            %endif
            <use xlink:href="#sort_asc">
          </svg>
        </a>
        <a href="${h.url(controller='case_overview', action='overview',
                             sort_field=urlpart, sort_order='desc')}">
            %if c.sort_field == urlpart and c.sort_order == 'desc':
              <svg class="svg-sort-active" aria-labelledby="title" role="img">
                <title id="title">${_("Sorted by %s in descending order") % title}</title>
            %else:
              <svg class="svg-sort" aria-labelledby="title" role="img">
                <title id="title">${_("Sort in descending order")}</title>
            %endif
            <use xlink:href="#sort_desc">
          </svg>
        </a>
      </th>
    % endif
  % endfor
  <th class="table_status table_header_h">
    ${_('Status')}
  </th>
  <th class="table_action table_header_h">
  </th>
</%def>

<%def name="build_list_row(case)">
  % if g.mpuls_config.is_enabled('case-module', 'casebundle'):
    <td><input type="checkbox" name="case_id" value="${case.id}"></td>
  % endif
  % for title, urlpart, style, roles, get_value in fields:
    % if h.hasRole(roles):
      % if case.getState().getState() != 5:
        <td>
          <a href="${h.url(controller='case', action='select',
                           id=case.id, confirmed=0)}">
              ${get_value(case) | F.NA}
          </a>
        </td>
      % else:
        <td>${get_value(case) | F.NA}</td>
      % endif
    % endif
  % endfor
  <td>
    ${get_phase_icon(case)}
    % if g.mpuls_config.is_enabled('case-module', 'tags'):
        ${get_validity_icon(case)}
    % endif
    ${get_state_icon(case)}
  </td>
  <td class="icon-td">
    ${get_actions(case)}
  </td>
</%def>

<%def name="get_validity_icon(case)">
  % for validity in g.mpuls_config.get('validities', 'enabled'):
    % if validity['id'] == case.getValidity():  
      <img src="${h.url('/images/icons/%s' % validity['icon'])}" alt="${validity['name']}" title="${validity['name']}">
    % endif
  % endfor
</%def>

<%def name="get_phase_icon(case)">
  <% phase = c.statemachine.get_current_state(case) %>
  <% phase_id = phase.get_id() %>
  <% running = not phase_id%2 and 'running' or 'finished' %>
  <% description = h.literal(phase.get_display_name()) %>
  <% icon = phase.get_icon_name() %>
  <span title="${_('Status')}: ${description}">
    <svg class="svg-icon-disabled" aria-labelledby="title" role="img">
      <title id="title">${_('Status')}: ${description}</title>
      <use xlink:href="#${icon}_${running}" />
    </svg>
  </span>
  % if case.strukturdaten_abgeschlossen == '1':
    <span title="${_('Status')}: ${description}">
      <svg class="svg-icon-disabled" aria-labelledby="title" role="img">
        <title id="title">Strukturdaten abgeschlossen</title>
        <use xlink:href="#check" />
      </svg>
    </span>
  % else:
     <span title="${_('Status')}: ${description}">
      <svg class="svg-icon-disabled" aria-labelledby="title" role="img">
        <title id="title">Strukturdaten nicht abgeschlossen</title>
        <use xlink:href="#edit" />
      </svg>
    </span>
  %endif
</%def>

<%def name="render_phase_legend()">
<% legend = [] %>
<div class="info float-right">
  <strong>${_('Legend')}: </strong>
  <span title="${_('Status')}: ${_('Running')}">
    <svg class="svg-icon-disabled-small" aria-labelledby="title" role="img">
      <title id="title">${_('Status')}: ${_('Running')}</title>
      <use xlink:href="#phase-running" />
    </svg>
  </span>
  : ${_('Running')},
  <span title="${_('Status')}: ${_('Finished')}">
    <svg class="svg-icon-disabled-small" aria-labelledby="title" role="img">
      <title id="title">${_('Status')}: ${_('Finished')}</title>
      <use xlink:href="#phase-stop" />
    </svg>
  </span>
  : ${_('Finished')}
</div>
<br>
</%def>

<%def name="get_state_icon(case)">
  % if h.hasRole(['cm']) and g.mpuls_config.is_enabled('case-module', 'organisation'):
    % if str(case.getEditor().id) == str(session.get('USER_AUTHORIZED').id):
    <span title="${_('Status')}: ${_('Editor')}">
      <svg class="svg-icon-disabled" aria-labelledby="title" role="img">
        <title id="title">${_('Status')}: ${_('Editor')}</title>
        <use xlink:href="#edit_editor" />
      </svg>
    </span>
    % else:
    <span title="${_('Status')}: ${_('Standin')}">
      <svg class="svg-icon-disabled" aria-labelledby="title" role="img">
        <title id="title">${_('Status')}: ${_('Standin')}</title>
        <use xlink:href="#rep" />
      </svg>
    </span>
    % endif
  % endif
  % if case.getState().getState() == 3:
  <span title="${_('Status')}: ${_('Mark delete')}">
    <svg class="svg-icon-disabled" aria-labelledby="title" role="img">
      <title id="title">${_('Status')}: ${_('Mark delete')}</title>
      <use xlink:href="#delete" />
    </svg>
  </span>
  % elif case.getState().getState() == 4:
  <span title="${_('Status')}: ${_('Mark anonym')}">
    <svg class="svg-icon-disabled" aria-labelledby="title" role="img">
      <title id="title">${_('Status')}: ${_('Mark anonym')}</title>
      <use xlink:href="#anonymise" />
    </svg>
  </span>
  % elif case.getState().getState() == 5:
  <span title="${_('Status')}: ${_('Mark anonymousym')}">
    <svg class="svg-icon-disabled" aria-labelledby="title" role="img">
      <title id="title">${_('Status')}: ${_('Mark anonymousym')}</title>
      <use xlink:href="#anonymise" />
    </svg>
  </span>
  % endif
</%def>

<%def name="get_actions(case)">
  % if h.hasRole(['admin']):
    % if case.getState().getState() in (3, 5) and case.getPhase() != 1:
      <a href="${h.url(controller='case', action='delete', id=case.id,
                           confirmed=0)}"
         title="${_('Delete case')}">
        <svg class="svg-icon svg-warning" aria-labelledby="title" role="img">
          <title id="title">${_('Delete case')}</title>
          <use xlink:href="#delete" />
        </svg>
      </a>
    % endif
    % if case.getState().getState() == 4:
      % if g.mpuls_config.is_enabled('case-module', 'anonymize'):
        <a href="${h.url(controller='case', action='anonymize', id=case.id,
                             confirmed=0)}"
         title="${_('Anonymize case document')}">
          <svg class="svg-icon svg-warning" aria-labelledby="title" role="img">
            <title id="title">${_('Anonymize case document')}</title>
            <use xlink:href="#anonymise" />
          </svg>
        </a>
      % endif
    % endif
    % if case.getState().getState() in (3, 4):
      <a href="${h.url(controller='case', action='restore', id=case.id,
                       confirmed=0)}"
         title="${_('Restore case document')}">
        <svg class="svg-icon" aria-labelledby="title" role="img">
          <title id="title">${_('Restore case document')}</title>
          <use xlink:href="#refresh" />
        </svg>
      </a>
    % endif
  % elif h.hasRole(['cm']) and case.getState().getState() in (1, 2):
    % if g.mpuls_config.is_enabled('case-module', 'anonymize'):
      <a href="${h.url(controller='case',
                           action='markForAnonymizeFromOverview', id=case.id,
                           confirmed=0)}"
         title="${_('Anonymize case document')}">
        <svg class="svg-icon svg-warning" aria-labelledby="title" role="img">
          <title id="title">${_('Anonymize case document')}</title>
          <use xlink:href="#anonymise" />
        </svg>
      </a>
    % endif
    % if case.getState().getPhase() != 1:
    <a href="${h.url(controller='case', action='markForDelete', id=case.id,
                         confirmed=0)}"
         title="${_('Delete')}">
        <svg class="svg-icon svg-warning" aria-labelledby="title" role="img">
          <title id="title">${_('Delete')}</title>
          <use xlink:href="#delete" />
        </svg>
     </a>
    % endif
  % endif
</%def>

<div class="table-responsive">
    <table id="table_caseoverview" class="table table-sm table-hover custom-table-striped">
      <thead>
      <tr>
        ${build_list_headers()}
      </tr>
      </thead>
      <tbody>
      % for num, case in enumerate(c.cases.getDatasets()):
          <tr class='clickable-row'
              data-href="${h.url(controller='case',  action='select',
                                 id=case.id, confirmed=0)}">
            ${build_list_row(case)}
          </tr>
      % endfor
      % if len(c.cases.getDatasets()) <= 0:
      <tr>
        <td colspan="5">
          ${_('No data found.')}
        </td>
        <td></td>
      </tr>
      % endif
      </tbody>
    </table>
 </div>
${render_phase_legend()}
