# -*- coding: utf-8 -*-

from string import Template
from cgi import escape

import mpulsweb.lib.helper.filters as F
from mpulsweb.lib.base import render
from mpulsweb.model.statement import Statement
from mpulsweb.model.agencysettings import Agency

class DiscretionStatement(Statement):
    def fillout(self):
        self.agency = Agency()
        s = {
            'VORNAME': escape(F.NA(self.case.first_name)),
            'NACHNAME': escape(F.NA(self.case.last_name)),
            'PLZ': escape(F.NA(self.case.plz)),
            'STRASSE': escape(F.NA(self.case.street)),
            'STRASSENR': escape(F.NA(self.case.streetnr)),
            'ORT': escape(F.NA(self.case.city)),
            'KA_NAME': escape(F.NA(self.agency.getName())),
            'KA_ADRESSE': escape(F.NA(self.agency.getAddress())),
            'KA_SPEICHERDAUER': escape(F.NA(self.agency.getMaxSavetime()))
            }
        return Template(render('/privacy/discretion_statement.html')).safe_substitute(s)


class PrivacyStatement(Statement):
    def fillout(self):
        self.agency = Agency()
        s = {
            'VORNAME': escape(underline(self.case.first_name, 20)),
            'NACHNAME': escape(underline(self.case.last_name, 20)),
            'PLZ': escape(F.no_none(self.case.plz)),
            'STRASSE': escape(F.no_none(self.case.street)),
            'STRASSENR': escape(F.no_none(self.case.streetnr)),
            'ORT': escape(underline(self.case.city, 24)),
            'KA_NAME': escape(underline(self.agency.getName(), 50)),
            'KA_ADRESSE': escape(F.no_none(self.agency.getAddress())),
            'KA_SPEICHERDAUER': escape(F.no_none(
                self.agency.getMaxSavetime()))
            }
        return Template(render('/privacy/default/privacy_statement.html')).safe_substitute(s)


def underline(text, n=None):
    if text == 'None' or not text:
        if n:
            return n*'_'
        else:
            return '-/-'
    return text
# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8:
