# -*- coding: utf-8 -*-
#
# Copyright 2007, 2008 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls WASKA (CoMPUter-based case fiLeS -
# Web-Anwendungs-Server fuer Kompetenzagenturen).
#
# mpuls WASKA is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls WASKA is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls WASKA. If not, see <http://www.gnu.org/licenses/>.
#
# mpuls WASKA has been developed on behalf of the
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and
# European Social Fund resources.
# Authors:
# Torsten Irländer <torsten.irlaender@intevation.de>
#

import logging
from string import Template
from cgi import escape

import mpulsweb.lib.helper.filters as F
from mpulsweb.lib.db import db


GET_STATEMENT_FLAG_SQL = """\
SELECT einwilligung from master_tbl_view WHERE id = %(id)s"""
SET_STATEMENT_FLAG_SQL = """\
SELECT set_ee_status(%(id)s, %(value)s)"""

log = logging.getLogger(__name__)


class Statement(object):

    def __init__(self, case, agency):
        self.case = case
        self.agency = agency

    def fillout(self):
        raise NotImplementedError

    def decline(self):
        pass

    def sign(self):
        pass

    def keepUndefined(self):
        pass

    def isSigned(self):
        return False


class PrivacyStatement(Statement):

    UNDEFINED = -1
    SIGNED = 1
    DECLINED = 0

    def fillout(self):
        ka = {'KA_NAME': escape(F.NA(self.agency.getName())),
              'KA_ADRESSE': escape(F.NA(self.agency.getAddress())),
              'KA_SPEICHERDAUER': escape(F.NA(self.agency.getMaxSavetime()))
              }
        f = {
            'VORNAME': 'first_name',
            'NACHNAME': 'last_name',
            'PLZ': 'plz',
            'STRASSE': 'street',
            'STRASSENR': 'streetnr',
            'ORT': 'city'
        }

        # Some of the fields used in the statement may not be part of the case.
        # So iterate over all fields and try to get the value from the case. If
        # value can not be get ignore it.
        ff = {}
        for k, v in f.iteritems():
            try:
                ff[k] = escape(F.NA(getattr(self.case, v)))
            except:
                log.warning('Can not get field %s' % k)

        ff.update(ka)
        return Template(self.agency.getPrivacyStatement()).safe_substitute(ff)

    def sign(self):
        db.execute(SET_STATEMENT_FLAG_SQL, {'id': self.case.id,
                                            'value': self.SIGNED})

    def keepUndefined(self):
        db.execute(SET_STATEMENT_FLAG_SQL, {'id': self.case.id,
                                            'value': self.UNDEFINED})

    def decline(self):
        db.execute(SET_STATEMENT_FLAG_SQL, {'id': self.case.id,
                                            'value': self.DECLINED})

    def isSigned(self):
        '''Returns True is teh statement is signed. False if the statement is
        _not_ signed and will not be signed in the future. None is returned if
        the statement is not signed yet, but might be signed in the future'''
        conn, cur = None, None
        try:
            conn = db.getConnection()
            cur = conn.cursor()
            cur.execute(GET_STATEMENT_FLAG_SQL, {'id': self.case.id})
            signed = cur.fetchone()[0]
            if signed == self.SIGNED:
                return True
            elif signed == self.DECLINED:
                return False
            elif signed == self.UNDEFINED:
                return None
        finally:
            db.recycleConnection(conn, cur)


# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8:
