#! /usr/bin/python
"""Prepare PLZ data for use in JMD
"""

import sys
import csv
import json
from collections import defaultdict


def load_csv(filename):
    """Read the data from a file and return a (HEADER, ROWS) pair
    """
    header = None
    rows = []
    with open(filename) as f:
        reader = csv.reader(f)
        for row in reader:
            if header is None:
                header = row
            else:
                rows.append(row)
    return header, rows


def project_ort_plz(rows):
    """Extract the columns "ort" and "plz" from the data

    The original data has the following columns:
        osm_id,ags,ort,plz,landkreis,bundesland

    We're only interested in ort and plz, so we just extract those columns.
    """
    return [(row[2], row[3]) for row in rows]


def write_js(filename, rows):
    with open(filename, "w") as f:
        f.write("plz_table = ")
        f.write(json.dumps(rows))


def main():
    input_filename = sys.argv[1]
    output_filename = sys.argv[2]
    header, rows = load_csv(input_filename)
    processed = project_ort_plz(rows)
    write_js(output_filename, processed)


main()

