#!/bin/bash

usage()
{
cat << EOF
usage: $0 options

This script excecutes the given SQL statement in the input file on all
available databases matching the typical mpuls database naming and
returns it output as comma separated line(s), one per database. This
script intended for quick analyses and evaluations.

OPTIONS:
   -h      Show this message
   -p      Port of the database (Default 5432)
   -d      List whitespace separated databases "uvw xyz"
           (Default: all databases printed by the dblist.sh script.)
   -c      SQL command
   -v      Verbose
EOF
}

# DEFAULTS
ARG1=${1}
VERBOSE=0
DBPORT=5432
DBLIST=""
COMMAND="select count(id) from master_tbl"

# Parse Options
while getopts "hvp:c:d:" OPTION
do
        case $OPTION in
            h)
                usage
                exit 1
                ;;
            p)
                DBPORT=$OPTARG
                ;;
            c)
                COMMAND=$OPTARG
                ;;
            d)
                DBLIST=$OPTARG
                ;;
            v)
                VERBOSE=1
                ;;
            ?)
                # Will be set if the optstring begins with a ":". In this case
                # all options not defined in the optstring will OPTION set to
                # "?". Otherwise the shell reports an error on the unknown
                # option.
                usage
                exit
                ;;
        esac
done

# Check Arguments
#if [[ -z $ARG1 ]]
#then
#    echo "Error! SQL-File required!";
#    usage;
#    exit 1;
#fi

# Check Options
if [[ $DBLIST = "" ]]
then
     DBLIST=`sh dblist.sh -p ${DBPORT}`
fi


# 2. Iterate over all databases and excecute the SQL-Statement in the SQL-Input file.
for DB in ${DBLIST};
do
    RESULT=`psql -p ${DBPORT} ka_${DB}_db -t -c "${COMMAND}" \
    | sed -e 's/ //g' \
    | sed -e 's/|/,/g' `;
    echo ${DB},${RESULT};
done;

exit 0;
