#!/bin/bash
# -------------------------------------------------------------------
# Copyright (C) 2016 by Intevation GmbH
# Author(s):
# Sascha Wilde <wilde@intevation.de>

# This program is free software under the GNU GPL (>=v2)
# Read the file COPYING coming with the software for details.
# -------------------------------------------------------------------

fatal()
{
  echo >&2 "$*"
  exit 23
}

[ $# -eq 3 ] || fatal "Usage: $0 PORT OLD_BD NEW_DB"
port=$1
old=$2
new=$3

log=$( date +db_rename_%Y%m%d-%T )

check_db_exists()
{
  cnt=$( psql -p $port -A -t -c "SELECT COUNT(*) FROM pg_database WHERE datname = 'ka_${old}_db';" )
  [ "$cnt" = "1" ] || fatal 'Old DB does not exist.'
}

rename_dbs()
{
  echo "ALTER DATABASE ka_${old}_db RENAME TO ka_${new}_db;"
  echo "ALTER DATABASE ka_st${old}_db RENAME TO ka_st${new}_db;"
}

rename_users()
{
  for prefix in "" "st" ; do
    users=$( psql -p $port -A -t -c "SELECT rolname FROM pg_roles WHERE rolname ~ '^ka_${prefix}${old}_';" )
    for user in $users ; do
      new_user=$( sed "s/_${prefix}${old}_/_${prefix}${new}_/" <<<$user )
      echo "ALTER ROLE $user RENAME TO $new_user;"
    done
  done
}

fix_benutzer_tbl()
{
  echo "UPDATE ka_benutzer_tbl SET login = regexp_replace(login, '^ka_${old}_(.*)', E'ka_${new}_\\\\\\\\1');"
}

set_adm_passwd()
{
  for prefix in "" "st" ; do
    passwd=$( pwgen -s -A 12 )
    echo "ALTER ROLE ka_${prefix}${new}_adm PASSWORD '${passwd}';"
  done
}

check_db_exists

sql="BEGIN;
`rename_dbs`
`rename_users`
`set_adm_passwd`
COMMIT;"

sql_local="BEGIN;
`fix_benutzer_tbl`
COMMIT;"

cmds=("psql -p $port -c \"$sql\""
      "psql -p $port -d ka_${new}_db -c \"$sql_local\""
      # We can use the same SQL for struktur db, as the entries in
      # ka_benutzer_tbl of the struktur db is not prefixed with st.
      "psql -p $port -d ka_st${new}_db -c \"$sql_local\""
     )

for cmd in "${cmds[@]}" ; do
  echo "$cmd"
done
read -p "Execute the above commands? (Then type DOIT): " doordont

if [ "$doordont" = "DOIT" ] ; then
    for cmd in  "${cmds[@]}" ; do
      echo "$cmd" >>"$log"
      # Yes, eval is evil, but I know what I'm doing, so trust me...
      # Muahahahaaaa!
      eval "$cmd" 2>&1 | tee -a "$log"
    done
else
  echo "No harm done..."
fi
