SET ROLE :adm_ka_owner;
BEGIN;

-- ka_status_tbl
--
-- Speichert Zustand und letzte Zugriffszeit der Fallakte.
-- Mögliche Zustände:
--      Offen (1)
--      Geschlossen (2)
--      Schwebend-Gelöscht (3)
--      Schwebend-Anonymisiert (4)
--      Anonymsiert (5)
--
-- Die Spalte master_id muss im Anschluss an die Erstellung der master_tbl
-- dann zu einem FK werden!

CREATE TABLE ka_status_tbl
(
        id serial NOT NULL,
        master_id int4,
        status    int4,
        zugriff   timestamp,
        erstellt  timestamp DEFAULT now(),
        anonymisiert timestamp,
        changed_editor BOOLEAN NOT NULL DEFAULT FALSE,
        CONSTRAINT ka_status_tbl_pkey PRIMARY KEY (id)
);

-- create_status_ds(mid integer)
-- legt einen statusdatensatz fuer eine Fallakte an
--
-- deletion of the entry is done by ON DELETE CONSTRAINT

CREATE OR REPLACE FUNCTION create_status_ds(mid integer)
    RETURNS VOID
    LANGUAGE 'plpgsql' VOLATILE SECURITY DEFINER
    AS $$
BEGIN
    INSERT INTO ka_status_tbl (master_id, zugriff, status)
            VALUES (mid, now(), 1);
END;
$$;

-- Trigger Logging

--
-- Automatisches Setzen eines Zeitstempels in der ka_status_tbl
-- Diese Trigger sorgen dafür, dass bei jeder Bearbeitung der Fallakten der
-- Zeitpunkt der Bearbeitung gespeichert wird.
--
CREATE OR REPLACE FUNCTION set_lastaccess_time( masterid integer ) 
RETURNS void AS 
$$
BEGIN
    UPDATE ka_status_tbl_view set zugriff = now() WHERE master_id = masterid;  
END;
$$ LANGUAGE plpgsql VOLATILE;

CREATE OR REPLACE FUNCTION master_lastaccess_log() RETURNS trigger AS $master_lastaccess_log$
BEGIN
    EXECUTE set_lastaccess_time(NEW.id);
    RETURN NEW;
END;
$master_lastaccess_log$ LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION status_lastaccess_log() RETURNS trigger AS $status_lastaccess_log$
BEGIN
IF NEW.status <> OLD.status AND OLD.zugriff IS NOT NULL THEN
    EXECUTE set_lastaccess_time(NEW.master_id);
END IF;
RETURN NEW;
END;
$status_lastaccess_log$ LANGUAGE plpgsql;

COMMIT;
-- Create Views.
\i sql/install/views/04_status.sql
