#!/bin/bash

usage()
{
cat << EOF
usage: $0 options distroname 

This script will create a new distribution.

OPTIONS:
   -h       Show this message
EOF
}

DIST=${1};
PATH_MODULES=/home/projects/mpuls/src/modules/available/$DIST
PATH_DISTRO=/home/projects/mpuls/src/distribution/$DIST


# Parse Options
while getopts "h" OPTION
do
        case $OPTION in
            h)
                usage
                exit 1
                ;;
            ?)
                # Will be set if the optstring begins with a ":". In this case
                # all options not defined in the optstring will OPTION set to
                # "?". Otherwise the shell reports an error on the unknown
                # option.
                usage
                exit
                ;;
        esac
done

# Check if distribution dir exists
if [ -d $PATH_MODULES ]
then
    echo "Error! Modules directory ${PATH_MODULES} already exist!";
    exit 1;
fi

if [ -d $PATH_DISTRO ]
then
    echo "Error! Distribution directory ${PATH_DISTRO} already exist!";
    exit 1;
fi

echo "Creating new distribution ${DIST}";

#############
#  MODULES  #
#############
mkdir $PATH_MODULES
cd $PATH_MODULES

# Create application folder
mkdir application
cd application
hg init
echo -e "0.0\n===\n- Initial version" > CHANGES
hg add CHANGES
hg ci -m "Initial commit"
cd ..

# Create application-db folder
hg clone /home/projects/mpuls/src/modules/available/TEMPLATES/application-db

# Create config folder
hg clone /home/projects/mpuls/src/modules/available/TEMPLATES/config

# Create form folder
hg clone /home/projects/mpuls/src/modules/available/TEMPLATES/form

# Create evaluation folder
mkdir evaluation
cd evaluation
hg init
echo -e "0.0\n===\n- Initial version" > CHANGES
hg add CHANGES
hg ci -m "Initial commit"
cd ..

# Create specification folder
mkdir specification
cd specification
hg init
echo -e "0.0\n===\n- Initial version" > CHANGES
hg add CHANGES
hg ci -m "Initial commit"
cd ..

##################
#  DISTRIBUTION  #
##################
mkdir $PATH_DISTRO
cd $PATH_DISTRO
mkdir $DIST
hg init
touch .hgsub
echo "libformed = /home/projects/mpuls/src/modules/available/libformed/" >> .hgsub
echo "libmpuls = /home/projects/mpuls/src/modules/available/libmpuls/" >> .hgsub
echo "base = /home/projects/mpuls/src/modules/available/base" >> .hgsub
echo "evaluation-transfer = /home/projects/mpuls/src/modules/available/evaluation-transfer" >> .hgsub
echo "db-admin = /home/projects/mpuls/src/modules/available/db_scripts" >> .hgsub
echo "maintenance = /home/projects/mpuls/src/modules/available/maintenance" >> .hgsub
echo "" >> .hgsub
echo "application = /home/projects/mpuls/src/modules/available/$DIST/application" >> .hgsub
echo "application-db = /home/projects/mpuls/src/modules/available/$DIST/application-db" >> .hgsub
echo "specification = /home/projects/mpuls/src/modules/available/$DIST/specification" >> .hgsub
echo "form = /home/projects/mpuls/src/modules/available/$DIST/form" >> .hgsub
echo "config = /home/projects/mpuls/src/modules/available/$DIST/config" >> .hgsub
echo "evaluation = /home/projects/mpuls/src/modules/available/$DIST/evaluation" >> .hgsub
hg add .hgsub
hg ci -m "Initial commit"

# Switch to script-refactor branch
cd db-admin
hg pull -u
hg update script-refactor
cd ..
hg ci -m "Switched to script-refactor branch"

# Generate initial db_scripts
cd form
hg pull -u
cd ..
cd application-db
hg pull -u
cd ..

cd libformed
hg pull -u
cd scripts
python convert.py -f sql ../../form/formedtree.xml ../../application-db/install/01master.sql
python convert.py -f rg_sql ../../form/formedtree.xml ../../application-db/install/02rgroup.sql

cd ../../application-db
hg add
hg ci -m "Added initial SQL files"
hg push

cd ..
hg ci -m "Added initial SQL files"

echo Finished.
echo Checkout new distibution with "hg clone $PATH_DISTRO"
